@@ -3,10 +3,11 @@ profileDesign <- function (..., lower, upper, nprof,
   prof <- list(...)
   pvars <- names(prof)
   if (any(pvars==""))
-    stop(sQuote("profileDesign"),": you cannot profile over an unnamed variable!")
+    stop("in ",sQuote("profileDesign"),": you cannot profile over an unnamed variable!",call.=FALSE)
   ovars <- names(lower)
   if (!all(sort(ovars)==sort(names(upper))))
-    stop(sQuote("profileDesign"),": names of ",sQuote("lower")," and ",sQuote("upper")," must match!")
+    stop("in ",sQuote("profileDesign"),": names of ",sQuote("lower")," and ",
+         sQuote("upper")," must match!",call.=FALSE)
   x <- expand.grid(...,stringsAsFactors=stringsAsFactors)
   y <- sobolDesign(lower=lower,upper=upper,nseq=nprof)
   z <- vector(mode='list',length=nrow(x)*nprof)
